package Catmandu::CrossRef;
use strict;
use warnings;

our $VERSION = '0.006';

1;
__END__

=encoding utf-8

=head1 NAME

Catmandu::CrossRef - Catmandu modules for working with crossref data

=head1 STATUS

=begin HTML

<p>
<a href="https://travis-ci.org/LibreCat/Catmandu-CrossRef"><img src="https://travis-ci.org/LibreCat/Catmandu-CrossRef.svg?branch=master" alt="build status" /></a>
<a href="https://coveralls.io/r/LibreCat/Catmandu-CrossRef"><img src="https://coveralls.io/repos/LibreCat/Catmandu-CrossRef/badge.png?branch=master" alt="coverage status" /></a>
<a href="http://cpants.cpanauthors.org/dist/Catmandu-CrossRef"><img src="http://cpants.cpanauthors.org/dist/Catmandu-CrossRef.png" alt="kwalitee score" /></a>
</p>

=end HTML

=head1 MODULES

=over

=item

L<Catmandu::Importer::CrossRef>

=back

=head1 AUTHOR

Vitali Peil C<< <vitali.peil at uni-bielefeld.de> >>

=head1 CONTRIBUTORS

Jakob Voss C<< <voss at gbv.de> >>

=head1 COPYRIGHT

This software is copyright (c) 2014 by Vitali Peil.

=head1 LICENSE

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

=cut
